#!/bin/bash -eux
#
# Copyright (c) 2021, aptpod,Inc.
#

readonly THISDIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"
RESET_REPO=false

function usage() {
    cat <<EOF
Usage:
  $0 [-d dirname] [-r]

Description:
  Bootstrap script for Jasmine board.

Options:
  -d    l4t kernel source directory(Linux_for_Tegra/sources/kernel).
  -r    Reset repository.
  -h    Show this message.
EOF
    exit 1
}

if [ "$OPTIND" = 1 ]; then
  while getopts d:rh OPT
  do
    case $OPT in
      d)
        L4T_KERNEL_DIR=$OPTARG
        ;;
      r)
        RESET_REPO=true
        ;;
      h | \?)
        usage
        ;;
    esac
  done
else
  echo "No installed getopts-command." 1>&2
  exit 1
fi

if [ -z "${L4T_KERNEL_DIR:-}" ]; then
  usage
fi

function reset_repo() {
  local repo=$1
  (cd $repo && git reset --hard HEAD)
  return 0
}

function apply_patch() {
  local pnum=$1
  local directory=$2
  local patchfiles=$3

  if $RESET_REPO; then
   reset_repo $directory
  fi

  pushd $(pwd) >/dev/null 2>&1

  cd $directory

  for patchfile in $patchfiles; do
    patch -p $pnum <$patchfile
  done

  popd >/dev/null 2>&1

  return 0
}

function apply_patchs() {
  apply_patch 1 kernel-4.9 "../aptpod/patch/kernel-4.9/*.patch"
  apply_patch 2 nvidia "../aptpod/patch/nvidia/*.patch"
  return 0
}

pushd $L4T_KERNEL_DIR

# copy aptpod files
rm -rf aptpod
mkdir -p aptpod
cp -r $THISDIR/* aptpod/

apply_patchs

popd
