#!/bin/bash -eu
#
# Copyright (c) 2021, aptpod,Inc.
#

readonly THISDIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

function usage() {
  cat <<EOF
Usage:
  $0 [-d dirname]

Description:
  Apply patches to kernel sources and rebuild the package.

Options:
  -k    Kernel source package (kernel_src.tbz2).
  -h    Show this message.
EOF
  exit 1
}

if [ "$OPTIND" = 1 ]; then
  while getopts k:h OPT; do
    case $OPT in
    k)
      KERNEL_PKG_FILE=$OPTARG
      ;;
    h | \?)
      usage
      ;;
    esac
  done
else
  echo "No installed getopts-command." 1>&2
  exit 1
fi

if [ -z "${KERNEL_PKG_FILE:-}" ] || [ ! -e "${KERNEL_PKG_FILE:-}" ]; then
  usage
fi

pkg_dir=$(dirname $KERNEL_PKG_FILE)
kernel_pkg_name=$(basename $KERNEL_PKG_FILE)
patched_kernel_pkg_dir=$pkg_dir/${kernel_pkg_name%.*}_patched

function extract_kernel_package {
  echo "Extract kernel package"

  rm -rf $patched_kernel_pkg_dir
  mkdir -p $patched_kernel_pkg_dir
  tar -xf $KERNEL_PKG_FILE -C $patched_kernel_pkg_dir
}

function apply_patches {
  echo "Apply patches"

  $THISDIR/bootstrap.sh -d $patched_kernel_pkg_dir/kernel
}

function fix_nvbuild_config_file {
  sed -i -e 's/config_file="tegra_defconfig"/config_file="jasmine_defconfig"/g' $patched_kernel_pkg_dir/nvbuild.sh
}

function compress_kernel_package {
  echo "Compress kernel package"

  tar -jcf "$pkg_dir/${kernel_pkg_name%.*}_patched.tbz2" -C $patched_kernel_pkg_dir .
  rm -rf $patched_kernel_pkg_dir

  echo "Successfully rebuild the kernel package. $pkg_dir/${kernel_pkg_name%.*}_patched.tbz2"
}

extract_kernel_package
apply_patches
fix_nvbuild_config_file
compress_kernel_package
